#
# spec file for package cosmic-store
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appname com.system76.CosmicStore
Name:           cosmic-store
Version:        1.0.0~alpha7+0
Release:        1.1
Summary:        COSMIC app store
License:        GPL-3.0-only
URL:            https://github.com/pop-os/cosmic-store
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  hicolor-icon-theme
BuildRequires:  just
BuildRequires:  pkgconfig
BuildRequires:  rust >= 1.80
BuildRequires:  pkgconfig(flatpak)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(xkbcommon)

%description
%{summary}.

%prep
%autosetup -a1

%build
just build-release

%install
just rootdir=%{buildroot} prefix=%{_prefix} install

%check
%{cargo_test}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{appname}.desktop
%{_datadir}/icons/hicolor/*/apps/%{appname}.svg
%{_datadir}/metainfo/%{appname}.metainfo.xml

%changelog
* Tue May  6 2025 Richard Rahl <rrahl0@opensuse.org>
- update vendor tarball, fixing bsc#1242678
* Thu Apr 24 2025 Richard Rahl <rrahl0@opensuse.org>
- Update to version 1.0.0~alpha7+0:
  * i18n - Update portuguese translations (#270)
  * i18n(be): update Belarusian translation (#268)
  * i18n(ro): Improve Romanian translation (#269)
  * empty commit to force rebuild
  * i18n (pt-BR) Update translations (#262)
  * Update com.system76.CosmicStore.desktop PL metadata
  * Update libcosmic
  * i18n(zh-CN): update zh-CN translation
  * fix(libcosmic): theme subscription
  * Update flathub stats
  * fix: Call `malloc_trim` only on glibc systems
  * i18n(pl): minor fix
  * i18n(sk): Update Slovak translations
  * Update Hungarian translations
* Sat Feb 22 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha6+0:
  * chore: upgrade dependencies
  * i18n(nl) improve Dutch translation
  * Add Polish translation to metainfo
  * Update cosmic_store.ftl
  * improve Dutch translation
  * Fixed Japanese translation for Cosmic Store
  * i18n(dk): Add Danish translation
  * Update Hungarian translations
- switch to obs_scm
* Sat Jan 18 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha5.1+0:
  * perf: optimized cosmic-freedesktop-icons
  * Update dependencies
  * packagekit(load_caches): Add cache-age hint and set it to 5 mins
* Fri Jan 10 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha5+1:
  * Update dependencies
  * Spell checked with LibreOffice
  * Update cosmic_store.ftl
  * Update (add) translation
  * improve & check for spelling the Dutch translation
  * Update flathub stats, mark debian/rules executable
  * Removed annoying popup dialog on canceling authentication with system packages
  * i18n(de): add German translation
  * Improve Dutch translation
  * Improve & Correct spelling Dutch translation
  * Remove a11y from default features
  * Update cosmic_store.ftl PL Translation operation fix
  * Added Irish translation
  * 18n pt-BR translation update
  * i18n(th): Add Thai translation
* Fri Dec  6 2024 rrahl0@opensuse.org
- Update to version 1.0.0~alpha4+0:
  * Update cosmic_store.ftl PL translation
  * update italian translation
  * update euro spanish translation
  * update french translation
  * update japanese translation
  * update libcosmic
  * fix: move button to top right corner
  * fix: info button not displaying when summary is long
  * Add progress notification
* Fri Nov  1 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha3:
  * Handle mime://
  * Add flatpakref mime type
  * Cleanup subcommand handling
  * Remove unnecessary clone
  * Re-run search after updating app info
  * Add installation from flatpakref
  * Correctly determine system package installed status
  * Auto open package when loading package file
  * Support for installing package files
  * Fix sort order of sources
  * Add support for system flatpaks
  * Add "Shop" to .desktop file keyword list
  * Make screenshot selectors insensitive if there is one or less screenshot
  * update translations
  * update dependencies
* Wed Sep 25 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha2:
  * Remove progress and timeout from notifications
  * update the notification-in-progress
  * improv: Cycle screenshots
  * fix: app open button
  * Fix navbar open in condensed mode by default
  * Improve initial load times
  * fix(header): make search button padding fixed
  * Update dependencies
  * Update translations
* Thu Aug  8 2024 Richard Rahl <rrahl0@opensuse.org>
- standardize packaging with also fixes for miscellaneous hardcoding
  filenames, using @PARENT_TAG where applicable, and be more specific
  with files in the %%files section (so no non-wanted files are getting
  added
* Wed Aug  7 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha1:
  * fix(libcosmic): double-click to maximize
  * update translations
- enable leap (thanks to vyvir)
* Wed Mar 13 2024 Richard Rahl <rrahl0@proton.me>
- initial packaging
